summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorJeongmo Yang <jm80.yang@samsung.com>2018-04-19 16:50:46 +0900
committerJeongmo Yang <jm80.yang@samsung.com>2018-04-19 16:50:46 +0900
commitf75ae545af3f4580e481e2d0a2164f19b76bdcc9 (patch)
tree876abde1bf3c4289310a7cbb88244b963743a7ba /include
parent4e9ce6cf52535f2623cfb9c7197128b1a1da5cec (diff)
downloadmm-hal-interface-f75ae545af3f4580e481e2d0a2164f19b76bdcc9.tar.gz
mm-hal-interface-f75ae545af3f4580e481e2d0a2164f19b76bdcc9.tar.bz2
mm-hal-interface-f75ae545af3f4580e481e2d0a2164f19b76bdcc9.zip
[camera] Update interfacesubmit/tizen/20180420.063541
[Version] 0.0.6 [Profile] Common [Issue Type] Update [Dependency module] N/A Change-Id: If02c5ae368efff116f028ff44ee35958ef39070d Signed-off-by: Jeongmo Yang <jm80.yang@samsung.com>
Diffstat (limited to 'include')
-rw-r--r--include/camera/tizen-camera.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/include/camera/tizen-camera.h b/include/camera/tizen-camera.h
index 399ae96..3dbb38d 100644
--- a/include/camera/tizen-camera.h
+++ b/include/camera/tizen-camera.h
@@ -34,8 +34,9 @@ extern "C" {
#define BUFFER_PLANE_MAX 4
#define DEVICE_COUNT_MAX 16
-#define DEVICE_NAME_LENGTH_MAX 32
#define RESOLUTION_COUNT_MAX 10
+#define DEVICE_NAME_LENGTH_MAX 16
+#define DEVICE_NODE_PATH_LENGTH_MAX 16
/**
* @addtogroup TIZEN_CAMERA_HAL_MODULE
@@ -127,8 +128,8 @@ typedef enum camera_pixel_format {
CAMERA_PIXEL_FORMAT_ARGB8888,
/* ENCODED */
- CAMERA_PIXEL_FORMAT_ENCODED_JPEG,
- CAMERA_PIXEL_FORMAT_ENCODED_H264,
+ CAMERA_PIXEL_FORMAT_JPEG,
+ CAMERA_PIXEL_FORMAT_H264,
/* MAX */
CAMERA_PIXEL_FORMAT_MAX
@@ -450,7 +451,8 @@ typedef struct camera_resolution_list {
*/
typedef struct camera_device_info {
uint32_t index;
- const char *name;
+ char name[DEVICE_NAME_LENGTH_MAX];
+ char node_path[DEVICE_NODE_PATH_LENGTH_MAX];
camera_facing_direction_t facing_direction;
camera_format_list_t format_list;
camera_resolution_list_t preview_list;
@@ -459,13 +461,13 @@ typedef struct camera_device_info {
} camera_device_info_t;
/**
- * @brief The structure type of the camera device list.
+ * @brief The structure type of the camera device information list.
* @since_tizen 3.0
*/
-typedef struct camera_device_list {
+typedef struct camera_device_info_list {
uint32_t count;
camera_device_info_t device_info[DEVICE_COUNT_MAX];
-} camera_device_list_t;
+} camera_device_info_list_t;
/**
* @brief Enumeration for the camera message type.
@@ -545,7 +547,7 @@ typedef int (*camera_capture_cb)(camera_buffer_t *main, camera_buffer_t *postvie
typedef struct camera_interface {
int (*init)(void **camera_handle);
int (*deinit)(void *camera_handle);
- int (*get_device_list)(void *camera_handle, camera_device_list_t *device_list);
+ int (*get_device_info_list)(camera_device_info_list_t *device_info_list);
int (*open_device)(void *camera_handle, int device_index);
int (*close_device)(void *camera_handle);
int (*add_message_callback)(void *camera_handle, camera_message_cb callback, void *user_data, uint32_t *cb_id);
@@ -600,14 +602,14 @@ int camera_deinit(void *camera_handle);
/**
* @brief Gets the device list of camera.
* @since_tizen 3.0
* @param[in] camera_handle The handle to the camera HAL
* @param[out] device_list The device list of the camera
* @return @c 0 on success, otherwise a negative error value
* @retval #CAMERA_ERROR_NONE Successful
* @retval #CAMERA_ERROR_INVALID_PARAMETER Invalid parameter
+ * @retval #CAMERA_ERROR_OUT_OF_MEMORY Out of memory
* @retval #CAMERA_ERROR_DEVICE_NOT_SUPPORTED The feature is not supported
*/
-int camera_get_device_list(void *camera_handle, camera_device_list_t *device_list);
+int camera_get_device_info_list(camera_device_info_list_t *device_info_list);
/**
* @brief Opens camera device.
@@ -600,14 +602,14 @@ int camera_deinit(void *camera_handle);
* @brief Gets the device list of camera.
* @since_tizen 3.0
- * @param[in] camera_handle The handle to the camera HAL
- * @param[out] device_list The device list of the camera
+ * @param[out] device_info_list The list of the camera device information
* @return @c 0 on success, otherwise a negative error value
* @retval #CAMERA_ERROR_NONE Successful